@@ -8,11 +8,14 @@
 
 //! An ICMPv6 packet abstraction.
 
-use ip::IpNextHeaderProtocols;
-use PrimitiveValues;
+use crate::ip::IpNextHeaderProtocols;
+use crate::PrimitiveValues;
+
+use alloc::vec::Vec;
+
 use pnet_macros::packet;
 use pnet_macros_support::types::*;
-use std::net::Ipv6Addr;
+use pnet_base::core_net::Ipv6Addr;
 
 /// Represents the "ICMPv6 type" header field.
 #[derive(Copy, Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
@@ -75,14 +78,15 @@ pub struct Icmpv6 {
 
 /// Calculates a checksum of an ICMPv6 packet.
 pub fn checksum(packet: &Icmpv6Packet, source: &Ipv6Addr, destination: &Ipv6Addr) -> u16be {
-    use Packet;
-    use util;
+    use crate::Packet;
+    use crate::util;
 
     util::ipv6_checksum(packet.packet(), 1, &[], source, destination, IpNextHeaderProtocols::Icmpv6)
 }
 
 #[cfg(test)]
 mod checksum_tests {
+    use alloc::vec;
     use super::*;
 
     #[test]
@@ -118,7 +122,7 @@ mod checksum_tests {
 #[allow(non_snake_case)]
 #[allow(non_upper_case_globals)]
 pub mod Icmpv6Types {
-    use icmpv6::Icmpv6Type;
+    use crate::icmpv6::Icmpv6Type;
     /// ICMPv6 type for "destination unreachable".
     pub const DestinationUnreachable: Icmpv6Type = Icmpv6Type(1);
     /// ICMPv6 type for "packet too big".
@@ -149,17 +153,20 @@ pub mod ndp {
     //!
     //! [RFC 4861]: https://tools.ietf.org/html/rfc4861
 
-    use icmpv6::{Icmpv6Code, Icmpv6Type};
-    use PrimitiveValues;
-    use Packet;
+    use crate::icmpv6::{Icmpv6Code, Icmpv6Type};
+    use crate::PrimitiveValues;
+    use crate::Packet;
+
+    use alloc::vec::Vec;
+
     use pnet_macros::packet;
     use pnet_macros_support::types::*;
-    use std::net::Ipv6Addr;
+    use pnet_base::core_net::Ipv6Addr;
 
     #[allow(non_snake_case)]
     #[allow(non_upper_case_globals)]
     pub mod Icmpv6Codes {
-        use icmpv6::Icmpv6Code;
+        use crate::icmpv6::Icmpv6Code;
         /// 0 is the only available ICMPv6 Code for the NDP.
         pub const NoCode: Icmpv6Code = Icmpv6Code(0);
     }
@@ -561,7 +568,8 @@ pub mod ndp {
 
     #[cfg(test)]
     mod ndp_tests {
-        use icmpv6::{Icmpv6Types, Icmpv6Code};
+        use alloc::vec;
+        use crate::icmpv6::{Icmpv6Types, Icmpv6Code};
         use super::*;
 
         #[test]
@@ -825,3 +833,167 @@ pub mod ndp {
         }
     }
 }
+
+pub mod echo_reply {
+    //! abstraction for "echo reply" ICMPv6 packets.
+    //!
+    //! ```text
+    //! +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+    //! |     Type      |     Code      |          Checksum             |
+    //! +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+    //! |           Identifier          |        Sequence Number        |
+    //! +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+    //! |     Data ...
+    //! +-+-+-+-+-
+    //! ```
+
+    use crate::PrimitiveValues;
+    use crate::icmpv6::{Icmpv6Code, Icmpv6Type};
+
+    use alloc::vec::Vec;
+
+    use pnet_macros::packet;
+    use pnet_macros_support::types::*;
+
+    /// Represents the identifier field.
+    #[derive(Copy, Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
+    pub struct Identifier(pub u16);
+
+    impl Identifier {
+        /// Create a new `Identifier` instance.
+        pub fn new(val: u16) -> Identifier {
+            Identifier(val)
+        }
+    }
+
+    impl PrimitiveValues for Identifier {
+        type T = (u16,);
+        fn to_primitive_values(&self) -> (u16,) {
+            (self.0,)
+        }
+    }
+
+    /// Represents the sequence number field.
+    #[derive(Copy, Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
+    pub struct SequenceNumber(pub u16);
+
+    impl SequenceNumber {
+        /// Create a new `SequenceNumber` instance.
+        pub fn new(val: u16) -> SequenceNumber {
+            SequenceNumber(val)
+        }
+    }
+
+    impl PrimitiveValues for SequenceNumber {
+        type T = (u16,);
+        fn to_primitive_values(&self) -> (u16,) {
+            (self.0,)
+        }
+    }
+
+    /// Enumeration of available ICMPv6 codes for "echo reply" ICMPv6 packets. There is actually only
+    /// one, since the only valid ICMPv6 code is 0.
+    #[allow(non_snake_case)]
+    #[allow(non_upper_case_globals)]
+    pub mod Icmpv6Codes {
+        use crate::icmpv6::Icmpv6Code;
+        /// 0 is the only available ICMPv6 code for "echo reply" ICMPv6 packets.
+        pub const NoCode: Icmpv6Code = Icmpv6Code(0);
+    }
+
+    /// Represents an "echo reply" ICMPv6 packet.
+    #[packet]
+    pub struct EchoReply {
+        #[construct_with(u8)]
+        pub icmpv6_type: Icmpv6Type,
+        #[construct_with(u8)]
+        pub icmpv6_code: Icmpv6Code,
+        pub checksum: u16be,
+        pub identifier: u16be,
+        pub sequence_number: u16be,
+        #[payload]
+        pub payload: Vec<u8>,
+    }
+}
+
+pub mod echo_request {
+    //! abstraction for "echo request" ICMPv6 packets.
+    //!
+    //! ```text
+    //! +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+    //! |     Type      |     Code      |          Checksum             |
+    //! +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+    //! |           Identifier          |        Sequence Number        |
+    //! +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+    //! |     Data ...
+    //! +-+-+-+-+-
+    //! ```
+
+    use crate::PrimitiveValues;
+    use crate::icmpv6::{Icmpv6Code, Icmpv6Type};
+
+    use alloc::vec::Vec;
+
+    use pnet_macros::packet;
+    use pnet_macros_support::types::*;
+
+    /// Represents the identifier field.
+    #[derive(Copy, Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
+    pub struct Identifier(pub u16);
+
+    impl Identifier {
+        /// Create a new `Identifier` instance.
+        pub fn new(val: u16) -> Identifier {
+            Identifier(val)
+        }
+    }
+
+    impl PrimitiveValues for Identifier {
+        type T = (u16,);
+        fn to_primitive_values(&self) -> (u16,) {
+            (self.0,)
+        }
+    }
+
+    /// Represents the sequence number field.
+    #[derive(Copy, Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
+    pub struct SequenceNumber(pub u16);
+
+    impl SequenceNumber {
+        /// Create a new `SequenceNumber` instance.
+        pub fn new(val: u16) -> SequenceNumber {
+            SequenceNumber(val)
+        }
+    }
+
+    impl PrimitiveValues for SequenceNumber {
+        type T = (u16,);
+        fn to_primitive_values(&self) -> (u16,) {
+            (self.0,)
+        }
+    }
+
+    /// Enumeration of available ICMPv6 codes for "echo reply" ICMPv6 packets. There is actually only
+    /// one, since the only valid ICMPv6 code is 0.
+    #[allow(non_snake_case)]
+    #[allow(non_upper_case_globals)]
+    pub mod Icmpv6Codes {
+        use crate::icmpv6::Icmpv6Code;
+        /// 0 is the only available ICMPv6 code for "echo reply" ICMPv6 packets.
+        pub const NoCode: Icmpv6Code = Icmpv6Code(0);
+    }
+
+    /// Represents an "echo request" ICMPv6 packet.
+    #[packet]
+    pub struct EchoRequest {
+        #[construct_with(u8)]
+        pub icmpv6_type: Icmpv6Type,
+        #[construct_with(u8)]
+        pub icmpv6_code: Icmpv6Code,
+        pub checksum: u16be,
+        pub identifier: u16be,
+        pub sequence_number: u16be,
+        #[payload]
+        pub payload: Vec<u8>,
+    }
+}
