@@ -8,6 +8,7 @@
 
 //! Provides interfaces for interacting with packets and headers.
 #![allow(missing_docs)]
+#![deny(warnings)]
 #![no_std]
 #![macro_use]
 
@@ -23,6 +24,7 @@ extern crate pnet_macros;
 pub use pnet_macros_support::packet::*;
 
 pub mod arp;
+pub mod dhcp;
 pub mod ethernet;
 pub mod gre;
 pub mod icmp;
@@ -34,5 +36,7 @@ pub mod tcp;
 pub mod udp;
 pub mod usbpcap;
 pub mod vlan;
+pub mod sll;
+pub mod sll2;
 
 pub mod util;
